@@ -1,20 +1,26 @@
 from .item import Item
+from .artist import Artist
 from .album import Album
 from .song import Song
 
-class SearchResult(Item):
+class SearchResult:
 
     __main_element : str = "searchResult2"
 
     def __init__(self, data : dict):
-        super().__init__(data)
+        self.__item : Item = Item(data)
+
+    def getArtists(self) -> list[Song]:
+        return list(map(
+            lambda x : Artist(x), 
+            self.__item.getList([SearchResult.__main_element, "artist"])))
 
     def getAlbums(self) -> list[Album]:
         return list(map(
             lambda x : Album(x), 
-            self.getList([SearchResult.__main_element, "album"])))
+            self.__item.getList([SearchResult.__main_element, "album"])))
 
     def getSongs(self) -> list[Song]:
         return list(map(
             lambda x : Song(x), 
-            self.getList([SearchResult.__main_element, "song"])))
+            self.__item.getList([SearchResult.__main_element, "song"])))
